Package 'mapsf.gui'

Title: Create Thematic Maps Interactively
Description: A Shiny application to create thematic maps interactively, based on the mapsf package. Features include: a user-friendly interface to create and customize thematic maps without coding, support for various map types (choropleth, proportional symbols, etc.) and customization options (colors, legends, etc.), R code generation to ensure reproducibility and export options to save maps in different formats (PNG, PDF, etc.).
Authors: Matthieu Viry [cre, aut] (ORCID: <https://orcid.org/0000-0002-0693-8556>), Timothée Giraud [aut] (ORCID: <https://orcid.org/0000-0002-1932-3323>), Hugues Pecout [aut] (ORCID: <https://orcid.org/0000-0002-0246-0954>)
Maintainer: Matthieu Viry <[email protected]>
License: GPL (>= 3)
Version: 0.0.0.9000
Built: 2026-06-05 11:28:22 UTC
Source: https://codeberg.org/riatelab/mapsf.gui

Help Index


Run the mapsf.gui Shiny app

Description

Run the mapsf.gui Shiny app

Usage

run_app(data = NULL, viewer = "browser", stop_on_close = TRUE)

Arguments

data

Optional list of sf objects to load at launch

viewer

Viewer type: "browser" (default), "pane", or "dialog"

stop_on_close

If TRUE (default), the app will stop when the viewer is closed. Set to FALSE to keep the app running. Note that reloading the app in your browser (with F5 for example) counts as closing the viewer, so if you set this to TRUE, the app will stop when you reload it. Setting this to FALSE allows you to reload the app in your browser without stopping it, but you will need to stop the app manually (by doing Ctrl + C in the console) when you are done.

Value

This function opens a browser, a pane or a dialog and returns nothing.

Examples

## Not run: 
# Run the app in the browser with no data
run_app()

# Run the app in a dialog with no data
run_app(viewer = "dialog")

# Run the app with example data from mapsf package
mtq <- mapsf::mf_get_mtq()
run_app(data = list(mtq = mtq))

# Run the app with multiple example data and without stopping on close
# (so that you can reload it in the browser without stopping it)
mtq <- mapsf::mf_get_mtq()
pts <- mapsf::mf_get_mtq("points")
run_app(data = list(mtq = mtq, pts = pts), stop_on_close = FALSE)

## End(Not run)